.. title:: Weblate Documentation

.. include:: ../README.rst

.. include:: toc-user.rst

.. include:: toc-admin.rst

.. include:: toc-devel.rst

.. include:: toc-contrib.rst

.. include:: toc-changes.rst

Indices and tables
------------------

* :ref:`genindex`
* :ref:`http-routingtable`
* :ref:`py-modindex`
